@@ -1,16 +1,14 @@
-try:
-    from importlib import import_module
-except ImportError:
-    from django.utils.importlib import import_module
+from importlib import import_module
+
+from django import template
 
 from classytags.arguments import Argument, Flag
-from classytags.core import Tag, Options
+from classytags.core import Options, Tag
 from classytags.parser import Parser
-from django import template
-from django.conf import settings
 
 from sekizai.helpers import get_varname
 
+
 register = template.Library()
 
 
@@ -53,7 +51,7 @@ def import_processor(import_path):
 
 class SekizaiParser(Parser):
     def parse_blocks(self):
-        super(SekizaiParser, self).parse_blocks()
+        super().parse_blocks()
         self.blocks['nodelist'] = self.parser.parse()
 
 
@@ -69,7 +67,7 @@ class AddtoblockParser(Parser):
 class SekizaiTag(Tag):
     def render(self, context):
         if validate_context(context):
-            return super(SekizaiTag, self).render(context)
+            return super().render(context)
         return ''
 
 
@@ -92,7 +90,9 @@ class RenderBlock(Tag):
         if postprocessor:
             func = import_processor(postprocessor)
             data = func(context, data, name)
-        return '%s\n%s' % (data, rendered_contents)
+        return f'{data}\n{rendered_contents}'
+
+
 register.tag('render_block', RenderBlock)
 
 
@@ -108,6 +108,8 @@ class AddData(SekizaiTag):
         varname = get_varname()
         context[varname][key].append(value)
         return ''
+
+
 register.tag('add_data', AddData)
 
 
@@ -132,7 +134,9 @@ class WithData(SekizaiTag):
         context[variable] = data
         inner_contents = inner_nodelist.render(context)
         context.pop()
-        return '%s\n%s' % (inner_contents, rendered_contents)
+        return f'{inner_contents}\n{rendered_contents}'
+
+
 register.tag('with_data', WithData)
 
 
@@ -157,4 +161,6 @@ class Addtoblock(SekizaiTag):
         varname = get_varname()
         context[varname][name].append(rendered_contents)
         return ""
+
+
 register.tag('addtoblock', Addtoblock)
